# Table of Contents

- [application-modernization-start-initiative](<./application-modernization-start-initiative.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Step 6: Start Modernization](<./Step-6-Start-Modernization.md>)
  - [Visualize Changes with Reports](<./Step-6-Start-Modernization/Visualize-Changes-with-Reports.md>)
  - [Execute Transformations in an Initiative](<./Step-6-Start-Modernization/Execute-Transformations-in-an-Initiative.md>)
  - [Execute Transformations in Bulk with the Transformations Explorer](<./Step-6-Start-Modernization/Execute-Transformations-in-Bulk-with-the-Transformations-Explorer.md>)
